Tapedeck
========

Tapedeck finds and plays music across muiltiple sources and devices.

It's like a fresh box of blank tapes.

Motivation
----------

After decades of various physical media and enough spooled tape
to lasso the moon, we find ourselves at the internet.  Many large
collections of live music are available online for free: LEGALLY
traded by a resilient community of music fanatics.  Meanwhile, many
of us now own multiple networked devices that are capable of music
download, streaming, and playback.  We also own piles of media purchases
that (hopefully) still exist in physical format to be ripped.

Tapedeck strives to organize these collections of music and provide
a way for the owners to enjoy their stash.

    *And the band keeps playing on...*
        John Perry Barlow

Features
--------

* Music search on local fileystem and network
* Bittorrent client
* RSS browser to list torrents
* Music player with network streaming
* Gapless playback
* CLI, REST, and Web interfaces
* Playlist manager
* Song lyrics with PDF output
* Meta tag display and discovery

Requirements
------------
* python3
* aria2
* ffmpeg
* postgresql
* icecast2
